@@ -4,4 +4,6 @@ pub use sqlx::{self, Row};
 
 #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
 pub use sqlx::any;
-pub use serde_json::{Value as Json, json};
\ No newline at end of file
+pub use async_trait;
+pub use anyhow;
+pub use serde_json::{self, Value as Json, json};
\ No newline at end of file
