@@ -1,8 +1,9 @@
-use arel::{ArelAble};
-use serde_json::json;
+use arel::prelude::*;
 
 #[arel::arel]
-struct User {}
+struct User {
+    id: i64,
+}
 
 #[cfg(test)]
 mod insert {
@@ -12,7 +13,7 @@ mod insert {
         let sql = User::create(json!({
             "name": "Tom",
             "age": 18,
-        })).to_sql().unwrap();
+        })).to_sql_string().unwrap();
         assert_eq!(sql, "INSERT INTO `users` (`age`, `name`) VALUES (18, 'Tom')");
     }
 }
\ No newline at end of file
